@@ -54,7 +54,7 @@ class Entry(BaseElement):
                 )
             if tags:
                 self._element.append(
-                    E.Tags(';'.join(tags) if type(tags) is list else tags)
+                    E.Tags(';'.join(tags) if isinstance(tags, list) else tags)
                 )
             self._element.append(
                 E.AutoType(
@@ -82,30 +82,45 @@ class Entry(BaseElement):
         """Get a string field from an entry
 
         Args:
-            key (str): name of field
+            key (`str`): name of field
 
         Returns:
-            (str or None): field value
+            `str` or `None`: field value
         """
 
         field = self._xpath('String/Key[text()="{}"]/../Value'.format(key), history=True, first=True)
         if field is not None:
             return field.text
 
-    def _set_string_field(self, key, value, protected=True):
+    def _set_string_field(self, key, value, protected=None):
         """Create or overwrite a string field in an Entry
 
         Args:
-            key (str): name of field
-            value (str): value of field
-            protected (bool): mark whether the field should be protected in memory
-                in other tools.  This property is ignored in PyKeePass and all
-                fields are decrypted immediately upon opening the database.
+            key (`str`): name of field
+            value (`str`): value of field
+            protected (`bool` or `None`): mark whether the field should be protected in memory
+                in other tools.  If `None`, value is either copied from existing field or field
+                is created with protected property unset.
+
+        Note: pykeepass does not support memory protection
         """
         field = self._xpath('String/Key[text()="{}"]/..'.format(key), history=True, first=True)
+
+        protected_str = None
+        if protected is None:
+            protected_field = self._xpath('String/Key[text()="{}"]/../Value'.format(key), first=True)
+            if protected_field is not None:
+                protected_str = protected_field.attrib.get("Protected")
+        else:
+            protected_str = str(protected)
+
         if field is not None:
             self._element.remove(field)
-        self._element.append(E.String(E.Key(key), E.Value(value, Protected=str(protected))))
+
+        if protected_str is None:
+            self._element.append(E.String(E.Key(key), E.Value(value)))
+        else:
+            self._element.append(E.String(E.Key(key), E.Value(value, Protected=protected_str)))
 
     def _get_string_field_keys(self, exclude_reserved=False):
         results = [x.find('Key').text for x in self._element.findall('String')]
@@ -116,7 +131,7 @@ class Entry(BaseElement):
 
     @property
     def index(self):
-        """int: get index of a entry within a group"""
+        """`int`: index of a entry within a group"""
         group = self.group._element
         children = group.getchildren()
         first_index = self.group._first_entry
@@ -127,7 +142,7 @@ class Entry(BaseElement):
         """Move entry to a new index within a group
         
         Args:
-            new_index (int): new index for the entry starting at 0
+            new_index (`int`): new index for the entry starting at 0
         """
         group = self.group._element
         first_index = self.group._first_entry
@@ -136,6 +151,7 @@ class Entry(BaseElement):
 
     @property
     def attachments(self):
+        """`list` of `Attachment`: attachments associated with entry"""
         return self._kp.find_attachments(
             element=self,
             filename='.*',
@@ -144,6 +160,17 @@ class Entry(BaseElement):
         )
 
     def add_attachment(self, id, filename):
+        """Add attachment to entry
+
+        The existence of a binary with the given `id` is not checked
+
+        Args:
+            id (`int`): ID of attachment in database
+            filename (`str`): filename to assign to this attachment data
+
+        Returns:
+            `Attachment`
+        """
         element = E.Binary(
             E.Key(filename),
             E.Value(Ref=str(id))
@@ -153,14 +180,16 @@ class Entry(BaseElement):
         return attachment.Attachment(element=element, kp=self._kp)
 
     def delete_attachment(self, attachment):
+        """remove an attachment from entry.  Does not remove binary data"""
         attachment.delete()
 
     def deref(self, attribute):
+        """See `PyKeePass.deref`"""
         return self._kp.deref(getattr(self, attribute))
 
     @property
     def title(self):
-        """str: get or set entry title"""
+        """get or set entry title"""
         return self._get_string_field('Title')
 
     @title.setter
@@ -169,7 +198,7 @@ class Entry(BaseElement):
 
     @property
     def username(self):
-        """str: get or set entry username"""
+        """`str`: get or set entry username"""
         return self._get_string_field('UserName')
 
     @username.setter
@@ -178,12 +207,15 @@ class Entry(BaseElement):
 
     @property
     def password(self):
-        """str: get or set entry password"""
+        """`str`: get or set entry password"""
         return self._get_string_field('Password')
 
     @password.setter
     def password(self, value):
-        return self._set_string_field('Password', value)
+        if self.password:
+            return self._set_string_field('Password', value)
+        else:
+            return self._set_string_field('Password', value, True)
 
     @property
     def url(self):
@@ -196,7 +228,7 @@ class Entry(BaseElement):
 
     @property
     def notes(self):
-        """str: get or set entry notes"""
+        """`str`: get or set entry notes"""
         return self._get_string_field('Notes')
 
     @notes.setter
@@ -205,7 +237,7 @@ class Entry(BaseElement):
 
     @property
     def icon(self):
-        """str: get or set entry icon. See icons.py"""
+        """`str`: get or set entry icon. See `icons`"""
         return self._get_subelement_text('IconID')
 
     @icon.setter
@@ -214,28 +246,31 @@ class Entry(BaseElement):
 
     @property
     def tags(self):
-        """str: get or set entry tags"""
+        """`str`: get or set entry tags"""
         val = self._get_subelement_text('Tags')
-        return val.replace(',', ';').split(';') if val else val
+        return val.replace(',', ';').split(';') if val else []
 
     @tags.setter
     def tags(self, value, sep=';'):
         # Accept both str or list
-        v = sep.join(value if type(value) is list else [value])
+        v = sep.join(value if isinstance(value, list) else [value])
         return self._set_subelement_text('Tags', v)
 
     @property
     def otp(self):
-        """str: get or set entry OTP text. (defacto standard)"""
+        """`str`: get or set entry OTP text. (defacto standard)"""
         return self._get_string_field('otp')
 
     @otp.setter
     def otp(self, value):
-        return self._set_string_field('otp', value)
+        if self.otp:
+            return self._set_string_field('otp', value)
+        else:
+            return self._set_string_field('otp', value, True)
 
     @property
     def history(self):
-        """:obj:`list` of :obj:`HistoryEntry`: get entry history"""
+        """`list` of `HistoryEntry`: get entry history"""
         if self._element.find('History') is not None:
             return [HistoryEntry(element=x, kp=self._kp) for x in self._element.find('History').findall('Entry')]
         else:
@@ -274,7 +309,7 @@ class Entry(BaseElement):
 
     @property
     def autotype_window(self):
-        """str: get or set [autotype target window filter](https://keepass.info/help/base/autotype.html#autowindows)"""
+        """`str`: get or set [autotype target window filter](https://keepass.info/help/base/autotype.html#autowindows)"""
         sequence = self._element.find('AutoType/Association/Window')
         if sequence is None or sequence.text == '':
             return None
@@ -286,7 +321,7 @@ class Entry(BaseElement):
 
     @property
     def is_a_history_entry(self):
-        """bool: check if entry is History entry"""
+        """`bool`: check if entry is History entry"""
         parent = self._element.getparent()
         if parent is not None:
             return parent.tag == 'History'
@@ -294,8 +329,8 @@ class Entry(BaseElement):
 
     @property
     def path(self):
-        """Path to element as list.  List contains all parent group names
-        ending with entry title.  List contains strings or NoneTypes."""
+        """`list` of (`str` or `None`): Path of entry.  List contains all parent group names
+        ending with entry title. May contain `None` for unnamed/untitled groups/entries."""
 
         # The root group is an orphan
         if self.parentgroup is None:
@@ -331,13 +366,17 @@ class Entry(BaseElement):
         specified key.
 
         Args:
-            key (:obj:`str`): key of the custom property to check.
+            key (`str`): key of the custom property to check.
 
         Returns:
-            bool: Whether the custom property is protected.
+            `bool`: Whether the custom property is protected.
 
         """
         assert key not in reserved_keys, '{} is a reserved key'.format(key)
+        return self._is_property_protected(key)
+
+    def _is_property_protected(self, key):
+        """Whether a property is protected."""
         field = self._xpath('String/Key[text()="{}"]/../Value'.format(key), first=True)
         if field is not None:
             return field.attrib.get("Protected", "False") == "True"
@@ -355,10 +394,10 @@ class Entry(BaseElement):
         """Create reference to an attribute of this element.
 
         Args:
-            attribute (str): one of 'title', 'username', 'password', 'url', 'notes', or 'uuid'
+            attribute (`str`): one of 'title', 'username', 'password', 'url', 'notes', or 'uuid'
 
         Returns:
-            str: [field reference][fieldref] to this field of this entry
+            `str`: [field reference][fieldref] to this field of this entry
 
         [fieldref]: https://keepass.info/help/base/fieldrefs.html
         """
@@ -373,10 +412,10 @@ class Entry(BaseElement):
         return '{{REF:{}@I:{}}}'.format(attribute_to_field[attribute], self.uuid.hex.upper())
 
     def save_history(self):
-        '''
+        """
         Save the entry in its history.  History is not created unless this function is
         explicitly called.
-        '''
+        """
         archive = deepcopy(self._element)
         hist = archive.find('History')
         if hist is not None:
@@ -392,8 +431,8 @@ class Entry(BaseElement):
         Delete entries from history
 
         Args:
-            history_entry (Entry): history item to delete
-            all (bool): delete all entries from history.  Default is False
+            history_entry (`Entry`): history item to delete
+            all (`bool`): delete all entries from history.  Default is False
         """
 
         if all:
@@ -403,7 +442,7 @@ class Entry(BaseElement):
 
     def __str__(self):
         # filter out NoneTypes and join into string
-        pathstr = '/'.join('' if p==None else p for p in self.path)
+        pathstr = '/'.join('' if p is None else p for p in self.path)
         return 'Entry: "{} ({})"'.format(pathstr, self.username)
 
 
